@@ -154,6 +154,15 @@ class MessageActionReportMixin(MessageContractIDMixin):
     """\
     A message mixin to describe an AR like message.
     """
+    STATUS_CROSS_DENIED = 100
+    STATUS_INSERTED = 200
+    STATUS_FILLED = 201
+    STATUS_NOFILL = 202
+    STATUS_CANCELED = 203
+
+    REASON_ERROR = 50
+    REASON_NOT_PERMITTED = 51
+
     @MessageField
     def inserted_price(self):
         if not self._inserted_price:
@@ -214,6 +223,16 @@ class MessageActionReportMixin(MessageContractIDMixin):
     def status_reason(self, val):
         self._status_reason = int(val)
 
+    @MessageField
+    def is_ask(self):
+        if not self._is_ask:
+            self._is_ask = False
+        return self._is_ask
+
+    @is_ask.setter
+    def is_ask(self, val):
+        self._is_ask = bool(val)
+
 @record_message_type
 class MessageLimitOrder(ClientMessage, MessageSubmissionMixin):
     """\
@@ -342,7 +361,7 @@ class MessageGetBookState(ClientMessage, MessageContractIDMixin):
     Type = 'get_book_state'
 
 @record_message_type
-class MessageBookState(ClientMessage, MessageContractIDMixin):
+class MessageBookState(ClientMessage, MessageContractIDMixin, MessageEntryIDMixin):
     """\
     A message to describe a book state.
     """
